Package: medfate
Type: Package
Title: Mediterranean Forest Simulation
Version: 5.1.0
Date: 2026-09-02
Authors@R: c(
	person('Miquel', 'De Cáceres', role=c('aut','cre', 'cph'),
	email='miquelcaceres@gmail.com', comment = c(ORCID = "0000-0001-7132-2080")),
	person('Nicolas', 'Martin-StPaul', role=c('aut'), comment = c(ORCID = "0000-0001-7574-0108")),
	person('Víctor', 'Granda', role='aut', comment = c(ORCID = "0000-0002-0469-1991")),
	person('Antoine', 'Cabon', role='aut', comment = c(ORCID = "0000-0001-6426-1726")),
  person('Arsène', 'Druel', role='aut', comment = c(ORCID = "0000-0002-3938-0085")),
	person('Julien', 'Ruffault', role='aut', comment = c(ORCID = "0000-0003-3647-8172")),
  person('Jordi', 'Martínez-Vilalta', role='ctb', comment = c(ORCID = "0000-0002-2332-7298")),
	person('Maurizio', 'Mencuccini', role='ctb', comment = c(ORCID = "0000-0003-0840-1477")),
	person('François', 'Pimont', role='ctb', comment = c(ORCID = "0000-0002-9842-6207")),
	person('Hervé', 'Cochard', role='ctb', comment = c(ORCID = "0000-0002-2727-7072")),
	person('Aitor', 'Améztegui', role='ctb', comment = c(ORCID = "0000-0003-2006-1559")),
	person('Léa', 'Veuillen', role='ctb', comment = c(ORCID = "0000-0002-2790-3627")),
	person('Shengli', 'Huang', role='ctb', comment = c(ORCID = "0000-0003-3927-7042")),
	person('John', 'Burkardt', role='cph', comment = c("Copyright holder of C++ code in 'incgamma.cpp'"))
	)
Description: Simulate Mediterranean forest functioning and dynamics using cohort-based description of vegetation [De Caceres et al. (2015) <doi:10.1016/j.agrformet.2015.06.012>; De Caceres et al. (2021) <doi:10.1016/j.agrformet.2020.108233>].
License: GPL (>= 2) | LGPL (>= 3)
URL: https://emf-creaf.github.io/medfate/,
        https://github.com/emf-creaf/medfate
BugReports: https://github.com/emf-creaf/medfate/issues
LazyLoad: yes
Depends: R (>= 3.5.0)
Imports: ggplot2 (>= 3.0.0), meteoland (>= 2.2.6), methods, Rcpp (>=
        1.0.6), RcppParallel, shiny, units
Suggests: testthat (>= 3.0.0), rlang, knitr, rmarkdown
LinkingTo: Rcpp, RcppArmadillo, RcppParallel, meteoland
SystemRequirements: GNU make
Encoding: UTF-8
NeedsCompilation: yes
Config/testthat/edition: 3
LazyData: true
Config/roxygen2/version: 8.0.0
Packaged: 2026-09-02 15:14:30 UTC; miquel
Author: Miquel De Cáceres [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0001-7132-2080>),
  Nicolas Martin-StPaul [aut] (ORCID:
    <https://orcid.org/0000-0001-7574-0108>),
  Víctor Granda [aut] (ORCID: <https://orcid.org/0000-0002-0469-1991>),
  Antoine Cabon [aut] (ORCID: <https://orcid.org/0000-0001-6426-1726>),
  Arsène Druel [aut] (ORCID: <https://orcid.org/0000-0002-3938-0085>),
  Julien Ruffault [aut] (ORCID: <https://orcid.org/0000-0003-3647-8172>),
  Jordi Martínez-Vilalta [ctb] (ORCID:
    <https://orcid.org/0000-0002-2332-7298>),
  Maurizio Mencuccini [ctb] (ORCID:
    <https://orcid.org/0000-0003-0840-1477>),
  François Pimont [ctb] (ORCID: <https://orcid.org/0000-0002-9842-6207>),
  Hervé Cochard [ctb] (ORCID: <https://orcid.org/0000-0002-2727-7072>),
  Aitor Améztegui [ctb] (ORCID: <https://orcid.org/0000-0003-2006-1559>),
  Léa Veuillen [ctb] (ORCID: <https://orcid.org/0000-0002-2790-3627>),
  Shengli Huang [ctb] (ORCID: <https://orcid.org/0000-0003-3927-7042>),
  John Burkardt [cph] (Copyright holder of C++ code in 'incgamma.cpp')
Maintainer: Miquel De Cáceres <miquelcaceres@gmail.com>
Repository: CRAN
Date/Publication: 2026-09-03 05:20:19 UTC
Built: R 4.5.2; aarch64-apple-darwin20; 2026-09-03 08:06:19 UTC; unix
Archs: medfate.so.dSYM
