import(ggplot2)
import(shiny)
import(methods)
importFrom("RcppParallel", "RcppParallelLibs")
importFrom("meteoland", "utils_atmosphericPressure", "utils_averageDailyVP",
           "utils_saturationVP", "penman")
importFrom("stats", "aggregate","filter","median",
           "cor","quantile", "dnorm", "Gamma", "glm", "predict",
           "rpois", "rbinom", "runif", "uniroot")
importFrom("grDevices", "rainbow")
importFrom("graphics", "axis", "abline", "barplot", "legend", "lines", "matplot","mtext",
           "matlines", "par", "polygon","axis.Date")
importFrom("utils", "data", "setTxtProgressBar", "txtProgressBar")
useDynLib(medfate, .registration = TRUE)
exportPattern("^[[:alpha:]]+")

importFrom(Rcpp, evalCpp)
S3method(plot,pwb)
S3method(plot,pwb_day)
S3method(plot,aspwb)
S3method(plot,spwb)
S3method(plot,spwb_day)
S3method(plot,growth)
S3method(plot,growth_day)
S3method(plot,fordyn)
S3method(plot,forest)
S3method(plot,soil)

S3method(shinyplot,pwb)
S3method(shinyplot,pwb_day)
S3method(shinyplot,aspwb)
S3method(shinyplot,spwb)
S3method(shinyplot,spwb_day)
S3method(shinyplot,growth)
S3method(shinyplot,growth_day)
S3method(shinyplot,fordyn)
S3method(shinyplot,forest)

S3method(summary, pwb)
S3method(summary, aspwb)
S3method(summary, spwb)
S3method(summary, growth)
S3method(summary, forest)
S3method(summary, fordyn)
S3method(print, summary.forest)
S3method(summary, soil)