#' medfate: Mediterranean Forest Simulation
#'
#' Simulate Mediterranean forest functioning and dynamics using cohort-based description of vegetation
#'
#' @name medfate-package
#' @aliases medfate medfate-package
#' @docType package
#' @author \strong{Maintainer}: Miquel De Cáceres
#' \email{miquelcaceres@@gmail.com}
#' [ORCID](https://orcid.org/0000-0001-7132-2080)
#'
#' Authors: \itemize{
#' \item{ Nicolas Martin-StPaul
#' [ORCID](https://orcid.org/0000-0001-7574-0108)}
#' \item{ Víctor Granda
#' [ORCID](https://orcid.org/0000-0002-0469-1991)}
#' \item{ Antoine Cabon
#' [ORCID](https://orcid.org/0000-0001-6426-1726)}
#' \item{ Arsène Druel
#' [ORCID](https://orcid.org/0000-0002-3938-0085)}
#' \item{ Julien Ruffault
#' [ORCID](https://orcid.org/0000-0003-3647-8172)}
#' }
#' Contributors: \itemize{
#' \item{ Jordi Martínez-Vilalta
#' [ORCID](https://orcid.org/0000-0002-2332-7298)}
#' \item{ Maurizio Mencuccini
#' [ORCID](https://orcid.org/0000-0003-0840-1477)}
#' \item{ François Pimont
#' [ORCID](https://orcid.org/0000-0002-9842-6207)}
#' \item{ Hervé Cochard
#' [ORCID](https://orcid.org/0000-0002-2727-7072)}
#' \item{ Aitor Améztegui
#' [ORCID](https://orcid.org/0000-0001-6426-1726)}
#' \item{ Léa Veuillen
#' [ORCID](https://orcid.org/0000-0002-2790-3627)}
#' \item{ Shengli Huang
#' [ORCID](https://orcid.org/0003-3927-7042)}
#' }
#' 
#' @seealso Useful links: 
#' \itemize{ 
#'  \item{\url{https://emf-creaf.github.io/medfate/}} 
#'  \item{\url{https://emf-creaf.github.io/medfatebook/}} 
#' }
#'
#' @references 
#' \itemize{
#'    \item{De Cáceres et al. (2015) (\doi{10.1016/j.agrformet.2015.06.012})}
#'    \item{De Cáceres et al. (2021) (\doi{10.1016/j.agrformet.2020.108233})}
#'    \item{Ruffault et al. (2022) (\doi{10.5194/gmd-15-5593-2022})}
#' }
#' 
#' @keywords internal
"_PACKAGE"
