% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/shinyplot.R
\name{shinyplot}
\alias{shinyplot}
\alias{shinyplot.growth}
\alias{shinyplot.aspwb}
\alias{shinyplot.spwb}
\alias{shinyplot.pwb}
\alias{shinyplot.fordyn}
\alias{shinyplot.growth_day}
\alias{shinyplot.spwb_day}
\alias{shinyplot.pwb_day}
\title{Shiny app with interactive plots}
\usage{
shinyplot(x, ...)

\method{shinyplot}{growth}(x, measuredData = NULL, ...)

\method{shinyplot}{aspwb}(x, measuredData = NULL, ...)

\method{shinyplot}{spwb}(x, measuredData = NULL, ...)

\method{shinyplot}{pwb}(x, measuredData = NULL, ...)

\method{shinyplot}{fordyn}(x, measuredData = NULL, ...)

\method{shinyplot}{growth_day}(x, ...)

\method{shinyplot}{spwb_day}(x, ...)

\method{shinyplot}{pwb_day}(x, ...)
}
\arguments{
\item{x}{An object of the right class.}

\item{...}{Additional parameters.}

\item{measuredData}{A data frame with observed/measured values (see \code{\link{evaluation_plot}}).}
}
\value{
An object that represents the shiny app
}
\description{
Creates a shiny app with interactive plots for simulation results and evaluation
}
\details{
Only run this function in interactive mode. When \code{measuredData} is not \code{NULL}, an additional panel is shown for evaluation plots.
}
\seealso{
\code{\link{plot.spwb}}, \code{\link{evaluation_plot}}
}
\author{
Miquel De \enc{Cáceres}{Caceres} Ainsa, CREAF
}
